@@ -4,10 +4,10 @@
 /*                                                              */
 /* Main Routine                                                 */
 /****************************************************************/
-/* bgpview.c,v 1.38 2001/09/27 02:45:40 kuniaki Exp */
+/* bgpview.c,v 1.43 2002/01/31 05:05:46 kuniaki Exp */
 
 /*
- * Copyright (c) 1998-2000 Internet Initiative Japan Inc.
+ * Copyright (c) 1998-2002 Internet Initiative Japan Inc.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -188,6 +188,7 @@ int init()
 	signal(SIGTERM, finish_sig);
 	signal(SIGHUP, restart_log);
 	signal(SIGPIPE, SIG_IGN);
+	signal(SIGCHLD, wait_sigchld);
 
 	bzero(peer,(sizeof(PEERS) * MAXPEERS));
 
@@ -267,6 +268,7 @@ int init()
 	}
 
 #ifndef LINUX
+#ifdef SO_REUSEPORT
 #ifdef DEBUG
 	printf("DEBUG: Set Socket Option: SO_REUSEPORT\n");
 #endif
@@ -277,6 +279,7 @@ int init()
 		perror("socket option(SO_REUSEPORT) set error (BGP)");
 		return(1);
 	}
+#endif /* SO_REUSEPORT */
 #endif /* LINUX */
 
 	/* cleate address & port BGP(179) */
@@ -823,7 +826,7 @@ void usage()
 	printf("       -v          : Version\n");
 	printf("       -f filename : Config File Name\n");
 	printf("		     (Defalut : %s)\n", CONF_FILE);
-	printf("       -d          : Daemon(Not Supported)\n");
+	printf("       -d          : Daemon\n");
 	printf("\n");
 }
 
@@ -840,6 +843,10 @@ int execoption(int opcn, char *val[])
 			usage();
 			return(1);
 		} else if (strcmp("-f", val[cnt]) == 0) {
+			if (val[cnt+1] == NULL) {
+				usage();
+				return(1);
+			}
 			strcpy(configfile, val[cnt+1]);
 			cnt++;
 		} else if (strcmp("-d", val[cnt]) == 0) {
