@@ -3,7 +3,7 @@
 /*                                                              */
 /* BGPView Shell Commands                                       */
 /****************************************************************/
-/* bvcommand.c,v 1.52 2001/09/27 02:45:40 kuniaki Exp */
+/* bvcommand.c,v 1.53 2001/10/01 11:39:38 kuniaki Exp */
 
 /*
  * Copyright (c) 2000 - 2001 Internet Initiative Japan Inc.
@@ -605,7 +605,7 @@ int bvc_shoproc(BVS_CMD_PARAM *prm)
 
 	close(wfp);
 	close(rfp);
-	while (wait((int *)0) != pid);
+	/* while (wait((int *)0) != pid); */
 	return(BVS_CNT_END);
 
 }
@@ -759,7 +759,7 @@ int bvc_shoversion(BVS_CMD_PARAM *prm)
 							syslogname);
 	} else {
 		sprintf(prline, "  Syslog Facility       : %s\r\n",
-							&syslogname[cnt+1]);
+							&syslogname[1]);
 	}
 	bvs_write(clno, prline);
 	sprintf(prline, "  Dummuy Route Config   : %s\r\n", dmyroutef);
