@@ -4,10 +4,10 @@
 /*                                                              */
 /* BGPView Shell 			                        */
 /****************************************************************/
-/* bvshell.c,v 1.56 2001/09/27 02:45:41 kuniaki Exp */
+/* bvshell.c,v 1.58 2002/01/31 05:05:46 kuniaki Exp */
 
 /*
- * Copyright (c) 2000 Internet Initiative Japan Inc.
+ * Copyright (c) 2000-2002 Internet Initiative Japan Inc.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -494,6 +494,7 @@ int bvs_init_start()
 	}
 
 #ifndef LINUX
+#ifdef SO_REUSEPORT
 #ifdef DEBUG
 	printf("DEBUG: BVS Set Socket Option: SO_REUSEPORT\n");
 #endif
@@ -504,6 +505,7 @@ int bvs_init_start()
 		perror("socket option(SO_REUSEPORT) set error (BVS)");
 		return(1);
 	}
+#endif /* SO_REUSEPORT */
 #endif /* LINUX */
 
 	sin.sin_family		= AF_INET;
