@@ -4,10 +4,10 @@
 /*                                                              */
 /* Start Configuration Routine                                  */
 /****************************************************************/
-/* config.c,v 1.27 2001/09/27 02:45:41 kuniaki Exp */
+/* config.c,v 1.29 2002/01/31 05:05:46 kuniaki Exp */
 
 /*
- * Copyright (c) 1998-2001 Internet Initiative Japan Inc.
+ * Copyright (c) 1998-2002 Internet Initiative Japan Inc.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -89,7 +89,11 @@ char *fname;
 			cnt++;
 		}
 #ifdef DEBUG
-		printf("CHECKING COMMAND = %s / VALUABLE = %s\n", cmd, val);
+		if (val == NULL) {
+			printf("CHECKING COMMAND = %s / VALUABLE = (NULL)\n", cmd);
+		} else {
+			printf("CHECKING COMMAND = %s / VALUABLE = %s\n", cmd, val);
+		}
 #endif
 		if (strcmp("LOCAL_AS", cmd) == 0) {
 			if (val == NULL) continue;
