@@ -4,7 +4,7 @@
 /*                                                              */
 /* Radix Tree Routine                                           */
 /****************************************************************/
-/* radix.c,v 1.22 2001/09/19 10:27:54 kuniaki Exp */
+/* radix.c,v 1.23 2001/10/23 09:20:28 kuniaki Exp */
 
 /*
  * Copyright (c) 1998-2000 Internet Initiative Japan Inc.
@@ -179,6 +179,13 @@ int add_route(ROUTE_INFO *rinfo)
 	c_leaf = radix_top;
 	scbit = 0;
 	while(1) {
+		/* Default Route Add */
+		if (rinfo->length == 0) {
+			ret = entry_route(radix_top, rinfo);
+			if (ret == 2) prefixes++;
+			break;
+		}
+
 		if ((rinfo->length)-1 > c_leaf->check_bit) {
 			cbit = c_leaf->check_bit;
 		} else {
@@ -309,7 +316,7 @@ int withdraw_route(int pn, net_ulong prefix, int masklen)
 
 	rcode = 0;
 	while(1) {
-	  if (node->check_bit > masklen-1) {
+	  if ((node->check_bit > masklen-1) && (masklen != 0)) {
 	    rcode = 1; /* no route */
 	    break;
 	  }
@@ -318,7 +325,11 @@ int withdraw_route(int pn, net_ulong prefix, int masklen)
 					ntohl(node->key), node->masklen);
 	  printf(" / Check_bit=%d\n", node->check_bit);
 #endif
-	  if ((node->key == prefix) && (node->masklen == masklen-1)) {
+	  if ( ((node->key == prefix) && (node->masklen == masklen-1)) ||
+	       							(masklen == 0)) {
+	    if (masklen == 0) {
+	      node = radix_top;
+	    }
 	    rlist = node->rinfo;
 	    if (rlist == NULL) {
 	      rcode = 1;
@@ -396,6 +407,7 @@ int withdraw_route(int pn, net_ulong prefix, int masklen)
 	        brlist = rlist;
 	        rlist = rlist->next;
 	      }
+	      if (node == radix_top) break;
 	      /* Back Track for Removing node */
 	      if (node->rinfo == NULL) {
 	        node->masklen = 0;
@@ -696,6 +708,13 @@ int withdraw_peer(int pn)
 		wdcode = delete_peer_route(&bnode, pn);
 		if (wdcode != 0) upcode = 0;
 	}
+
+#ifdef RTHISTORY
+	withdraw_route(pn, 0, 0, DELETE);
+#endif
+#ifndef RTHISTORY
+	withdraw_route(pn, 0, 0);
+#endif
 	return(0);
 }
 
@@ -707,6 +726,10 @@ RADIX_T *search_route(net_ulong prefix, int masklen)
 
 	node = radix_top;
 
+	if ((masklen == 0) || (prefix == 0)) {
+		return(radix_top);
+	}
+
 	while(1) {
 		if (node->check_bit > masklen-1) {
 			break;
