@@ -4,7 +4,7 @@
 /*                                                              */
 /* Timer Routine                                                */
 /****************************************************************/
-/* timer.c,v 1.9 2001/04/06 05:29:54 kuniaki Exp */
+/* timer.c,v 1.10 2001/09/19 10:27:54 kuniaki Exp */
 
 /*
  * Copyright (c) 1998-2001 Internet Initiative Japan Inc.
@@ -374,8 +374,12 @@ void execute_cron()
 	tv.tv_usec = 0;
 	cron_id = common_entry_timer(&tv, 0, execute_cron);
 	if (cron_id == -1) {
-		pr_log(VLOG_GLOB, LOG_ALL, "Cron Timer Set Fail\n", ON);
-		exit(1);
+		pr_log(VLOG_GLOB, LOG_ALL, 
+				"Cron Timer Set Fail : execute_cron\n", ON);
+		notify_systemnotify("REBOOT", 
+					"Cron Timer Set Fail : execute_cron");
+		finish(PROC_REBOOT);
+		return;
 	}
 
 	exec_cmdqueue();
