@@ -4,7 +4,7 @@
 /*                                                              */
 /* Utility functions                                            */
 /****************************************************************/
-/* utils.c,v 1.5 2001/09/14 07:08:12 kuniaki Exp */
+/* utils.c,v 1.7 2001/11/13 06:21:28 kuniaki Exp */
 
 /*
  * Copyright (c) 1998-2000 Internet Initiative Japan Inc.
@@ -121,7 +121,7 @@ int checkpw(char *encripted_strings, char *pass)
 
 	strncpy(salt, encripted_strings, 2);
 
-        strcpy(&encoded[0], crypt(pass, salt));
+        strcpy(&encoded[0], (char *)crypt(pass, salt));
 
 #ifdef DEBUG
         printf("DEBUG: CHACKPW: Phrase : %s\n",encripted_strings);
@@ -141,3 +141,8 @@ int checkpw(char *encripted_strings, char *pass)
         }
 }
 
+void wait_sigchld()
+{
+	while( waitpid(-1,NULL,WNOHANG) > 0 );
+}
+
