@@ -4,7 +4,7 @@
 /*                                                              */
 /* Utility Sub-routines                                         */
 /****************************************************************/
-/* utils.h,v 1.3 2001/09/14 07:08:12 kuniaki Exp */
+/* utils.h,v 1.4 2001/10/01 11:12:33 kuniaki Exp */
 
 /*
  * Copyright (c) 1998-2000 Internet Initiative Japan Inc.
@@ -37,6 +37,7 @@
 
 #include <sys/param.h>
 #include <sys/types.h>
+#include <sys/wait.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -44,6 +45,7 @@
 #include <unistd.h>
 
 
+
 #define OFF                     0
 #define ON                      1
 
@@ -66,5 +68,6 @@ extern void 	store_int16(/*ptr, var*/);
 extern void 	store_int32(/*ptr, var*/);
 extern boolean	chkfmt(/* int type, char *str */);
 extern int	checkpw(/* char *phrase, char *pass */);
+extern void 	wait_sigchld();
 
 #endif /* _UTILS_H */
